#!/usr/bin/env python

"""
Usage: alexes [USD]
Determine how much a given number of US Dollars are as a share of one Alex. $700 = 1 Alex.

The program performs global find & replace on every line of input. The text replaced is any $ and series of digits. The output is the corresponding fraction of an Alex, followed by the word 'Alex'; for example, '1/10 Alex'.

Numbers of Alexes greater than or equal to one are still expressed as fractions; for example, $1400 will result in the fraction "2/1", not simply 2. Expect this.

You may include the $ symbol, or not. Note that, because the fraction computer is precise, for best results, you should round the number of dollars up if it's a .99 number; for example, you should enter 19.99 as 20.
"""
# This is a variant of alexes.py, modified to act more reasonably as a service.

from fraction import fraction

def alexes(usd):
	"Returns a string expressing the fraction of one Alex that is closest to the given number of US Dollars. $700 = '1/1'."
	return '/'.join([str(int(x)) for x in fraction(usd / 700.0)])

import re
usd_exp = re.compile(r'\$(?P<USD>[0-9]+)(\.[0-9]+)?')
def replace_usd_with_alexes(match):
	return alexes(float(match.group('USD'))) + ' Alex'

if __name__ == "__main__":
	import sys
	for line in sys.stdin:
		sys.stdout.write(usd_exp.sub(replace_usd_with_alexes, line))
